Module test

Module test 

Test utilities for Gotham and Gotham consumer apps.

Re-exports

pub use self::request::TestRequest;
pub use crate::plain::test::TestServer;

Modules

request
Test request behavior, shared between the tls::test and plain::test modules.

Structs

AsyncTestClient
Client interface for issuing requests to an [AsyncTestServer].
AsyncTestRequestBuilder
Builder for a request made with an AsyncTestClient.
AsyncTestResponse
Wrapper around a Response with some helper methods. Response::from(test_response) can be used to get the underlying Response
TestClient
Client interface for issuing requests to a Server.
TestResponse
Wrapping struct for the Response returned by a TestClient. Provides access to the Response value via the Deref, DerefMut and Into traits, and also provides a function for awaiting a completed response body.

Traits

Server
An in memory server for testing purposes.